# -*- coding: utf-8 -*-

import urllib

import requests
from django.urls import reverse


class RemoteTestMixin:
    # ORGANIZATION ADDRESS
    def v1_organization_organization_address_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_organization_address_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_organization_address_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_organization_address_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_organization_address_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_organization_address_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_organization_address_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_organization_address_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_organization_address_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_organization_address_address_type_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-address-type-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # EMAIL TYPOLOGY

    def v1_organization_email_typology_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_email_typology_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_email_typology_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_email_typology_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_email_typology_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_email_typology_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_email_typology_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_email_typology_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_email_typology_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # PHONE TYPOLOGY

    def v1_organization_phone_typology_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_phone_typology_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_phone_typology_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_phone_typology_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_phone_typology_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_phone_typology_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_phone_typology_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_phone_typology_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_phone_typology_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION TYPE

    def v1_organization_organization_type_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_organization_type_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_organization_type_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_organization_type_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_organization_type_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_organization_type_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_organization_type_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_organization_type_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_organization_type_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION FORM

    def v1_organization_organization_form_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_organization_form_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_organization_form_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_organization_form_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_organization_form_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_organization_form_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_organization_form_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_organization_form_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_organization_form_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION

    def v1_organization_organization_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_organization_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_organization_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_organization_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_organization_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_organization_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_organization_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_organization_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_organization_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # OWNER ORGANIZATION

    def v1_organization_owner_organization_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_owner_organization_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_owner_organization_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_owner_organization_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_owner_organization_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_owner_organization_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_owner_organization_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_owner_organization_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_owner_organization_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION EMAIL

    def v1_organization_organization_email_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_organization_email_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_organization_email_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_organization_email_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_organization_email_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_organization_email_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_organization_email_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_organization_email_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_organization_email_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION PHONE

    def v1_organization_organization_phone_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_organization_phone_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_organization_phone_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_organization_phone_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_organization_phone_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_organization_phone_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_organization_phone_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_organization_phone_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_organization_phone_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION SOCIAL PAGE

    def v1_organization_organization_social_page_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_organization_social_page_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_organization_social_page_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_organization_social_page_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_organization_social_page_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_organization_social_page_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_organization_social_page_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_organization_social_page_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_organization_social_page_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT ROLE

    def v1_organization_contact_role_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_contact_role_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_contact_role_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_contact_role_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_contact_role_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_contact_role_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_contact_role_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_contact_role_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_contact_role_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT TITLE

    def v1_organization_contact_title_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_contact_title_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_contact_title_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_contact_title_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_contact_title_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_contact_title_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_contact_title_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_contact_title_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_contact_title_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT

    def v1_organization_contact_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_contact_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_contact_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_contact_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_contact_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_contact_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_contact_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_contact_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_contact_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # OWNER CONTACT

    def v1_organization_owner_contact_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_owner_contact_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_owner_contact_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_owner_contact_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_owner_contact_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_owner_contact_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_owner_contact_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_owner_contact_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_owner_contact_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT EMAIL

    def v1_organization_contact_email_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_contact_email_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_contact_email_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_contact_email_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_contact_email_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_contact_email_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_contact_email_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_contact_email_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_contact_email_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT PHONE

    def v1_organization_contact_phone_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_contact_phone_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_contact_phone_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_contact_phone_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_contact_phone_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_contact_phone_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_contact_phone_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_contact_phone_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_contact_phone_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT SOCIAL ACCOUNT

    def v1_organization_contact_social_account_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_contact_social_account_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_contact_social_account_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_contact_social_account_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_contact_social_account_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_contact_social_account_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_organization_contact_social_account_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_organization_contact_social_account_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_organization_contact_social_account_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp
