# -*- coding: utf-8 -*-
import swapper
from rest_framework import serializers
from thx.address.api.version1.serializers import AddressScopeLightSerializer
from thx.api.serializers import (
    ThuxCreateSerializerMixin, ThuxDisableSerializerMixin, ThuxEnableSerializerMixin, ThuxListSerializerMixin,
    ThuxPartialUpdateSerializerMixin, ThuxRetrieveSerializerMixin, ThuxUpdateSerializerMixin,
)
from thx.role.core.serializers import ThuxRoleSerializerMixin

from ... import models

Contact = swapper.load_model('organization', 'Contact')
Organization = swapper.load_model('organization', 'Organization')


# ORGANIZATION ADDRESS
class OrganizationAddressSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_address'
        model = models.OrganizationAddress
        fields = '__all__'


class OrganizationAddressListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    address_scopes = AddressScopeLightSerializer(many=True, read_only=True)
    country_name = serializers.CharField(source='country.name')

    class Meta:
        ref_name = 'v1_organization_organization_address_list'
        model = models.OrganizationAddress
        fields = (
            'id', 'status', 'status_display', 'organization', 'organization_name', 'org_name',
            'address_type', 'get_address_type_display', 'address_scopes',
            'name', 'number', 'zip_code', 'locality', 'province', 'country', 'country_name', 'ordering',
        )


class OrganizationAddressRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    address_scopes = AddressScopeLightSerializer(many=True, read_only=True)
    country_name = serializers.CharField(source='country.name')

    class Meta:
        ref_name = 'v1_organization_organization_address_retrieve'
        model = models.OrganizationAddress
        fields = (
            'id', 'status', 'status_display', 'organization', 'organization_name', 'org_name',
            'address_type', 'get_address_type_display', 'address_scopes', 'name', 'number',
            'zip_code', 'locality', 'province', 'country', 'country_name', 'ordering',
        )


class OrganizationAddressCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_address_create'
        model = models.OrganizationAddress
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationAddressRetrieveSerializer


class OrganizationAddressUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_address_update'
        model = models.OrganizationAddress
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationAddressRetrieveSerializer


class OrganizationAddressPartialUpdateSerializer(ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_address_partial_update'
        model = models.OrganizationAddress
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationAddressRetrieveSerializer


class OrganizationAddressEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_address_enable'
        model = models.OrganizationAddress
        fields = ()
        response_serializer = OrganizationAddressRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class OrganizationAddressDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_address_disable'
        model = models.OrganizationAddress
        fields = ()
        response_serializer = OrganizationAddressRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class OrganizationAddressLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    country_name = serializers.CharField(source='country.name')

    class Meta:
        ref_name = 'v1_organization_organization_address_light'
        model = models.OrganizationAddress
        fields = (
            'id', 'status', 'status_display', 'organization_name', 'org_name', 'address_type', 'name', 'number',
            'zip_code', 'locality', 'province', 'country_name', 'ordering',
        )


# EMAIL TYPOLOGY
class EmailTypologySerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_email_typology'
        model = models.EmailTypology
        fields = '__all__'


class EmailTypologyListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_email_typology_list'
        model = models.EmailTypology
        fields = ('id', 'status', 'status_display', 'code', 'name', 'slug', 'ordering')


class EmailTypologyRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_email_typology_retrieve'
        model = models.EmailTypology
        fields = ('id', 'status', 'status_display', 'code', 'name', 'slug', 'ordering')


class EmailTypologyCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_email_typology_create'
        model = models.EmailTypology
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = EmailTypologyRetrieveSerializer


class EmailTypologyUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_email_typology_update'
        model = models.EmailTypology
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = EmailTypologyRetrieveSerializer


class EmailTypologyPartialUpdateSerializer(ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_email_typology_partial_update'
        model = models.EmailTypology
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = EmailTypologyRetrieveSerializer


class EmailTypologyEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_email_typology_enable'
        model = models.EmailTypology
        fields = ()
        response_serializer = EmailTypologyRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class EmailTypologyDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_email_typology_disable'
        model = models.EmailTypology
        fields = ()
        response_serializer = EmailTypologyRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class EmailTypologyLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_email_typology_light'
        model = models.EmailTypology
        fields = ('id', 'status', 'status_display', 'name',)


# PHONE TYPOLOGY
class PhoneTypologySerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_phone_typology'
        model = models.PhoneTypology
        fields = '__all__'


class PhoneTypologyListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_phone_typology_list'
        model = models.PhoneTypology
        fields = ('id', 'status', 'status_display', 'code', 'name', 'slug', 'ordering')


class PhoneTypologyRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_phone_typology_retrieve'
        model = models.PhoneTypology
        fields = ('id', 'status', 'status_display', 'code', 'name', 'slug', 'ordering')


class PhoneTypologyCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_phone_typology_create'
        model = models.PhoneTypology
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = PhoneTypologyRetrieveSerializer


class PhoneTypologyUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_phone_typology_update'
        model = models.PhoneTypology
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = PhoneTypologyRetrieveSerializer


class PhoneTypologyPartialUpdateSerializer(ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_phone_typology_partial_update'
        model = models.PhoneTypology
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = PhoneTypologyRetrieveSerializer


class PhoneTypologyEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_phone_typology_enable'
        model = models.PhoneTypology
        fields = ()
        response_serializer = PhoneTypologyRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class PhoneTypologyDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_phone_typology_disable'
        model = models.PhoneTypology
        fields = ()
        response_serializer = PhoneTypologyRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class PhoneTypologyLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_phone_typology_light'
        model = models.PhoneTypology
        fields = ('id', 'status', 'status_display', 'name',)


# ORGANIZATION TYPE
class OrganizationTypeSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_type'
        model = models.OrganizationType
        fields = '__all__'


class OrganizationTypeListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_type_list'
        model = models.OrganizationType
        fields = ('id', 'status', 'status_display', 'code', 'name', 'category', 'get_category_display', 'ordering',)


class OrganizationTypeRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_type_retrieve'
        model = models.OrganizationType
        fields = ('id', 'status', 'status_display', 'code', 'name', 'category', 'get_category_display', 'ordering',)


class OrganizationTypeCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_type_create'
        model = models.OrganizationType
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationTypeRetrieveSerializer


class OrganizationTypeUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_type_update'
        model = models.OrganizationType
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationTypeRetrieveSerializer


class OrganizationTypePartialUpdateSerializer(ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_type_partial_update'
        model = models.OrganizationType
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationTypeRetrieveSerializer


class OrganizationTypeEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_type_enable'
        model = models.OrganizationType
        fields = ()
        response_serializer = OrganizationTypeRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class OrganizationTypeDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_type_disable'
        model = models.OrganizationType
        fields = ()
        response_serializer = OrganizationTypeRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class OrganizationTypeLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_type_light'
        model = models.OrganizationType
        fields = ('id', 'status', 'status_display', 'name',)


# ORGANIZATION FORM
class OrganizationFormSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_form'
        model = models.OrganizationForm
        fields = '__all__'


class OrganizationFormListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_form_list'
        model = models.OrganizationForm
        fields = ('id', 'status', 'status_display', 'code', 'name', 'ordering')


class OrganizationFormRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_form_retrieve'
        model = models.OrganizationForm
        fields = ('id', 'status', 'status_display', 'code', 'name', 'ordering')


class OrganizationFormCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_form_create'
        model = models.OrganizationForm
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationFormRetrieveSerializer


class OrganizationFormUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_form_update'
        model = models.OrganizationForm
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationFormRetrieveSerializer


class OrganizationFormPartialUpdateSerializer(ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_form_partial_update'
        model = models.OrganizationForm
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationFormRetrieveSerializer


class OrganizationFormEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_form_enable'
        model = models.OrganizationForm
        fields = ()
        response_serializer = OrganizationFormRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class OrganizationFormDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_form_disable'
        model = models.OrganizationForm
        fields = ()
        response_serializer = OrganizationFormRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class OrganizationFormLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_form_light'
        model = models.OrganizationForm
        fields = ('id', 'status', 'status_display', 'name',)


# ORGANIZATION
class OrganizationSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization'
        model = Organization
        fields = '__all__'


class OrganizationListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_list'
        model = Organization
        fields = (
            'id', 'status', 'status_display', 'category', 'organization_type', 'organization_type_name',
            'code', 'name', 'organization_form', 'organization_form_name', 'vat_number', 'ssn', 'email',
            'url', 'phone', 'ordering',
        )


class OrganizationRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_retrieve'
        model = Organization
        fields = (
            'id', 'status', 'status_display', 'category', 'organization_type', 'organization_type_name',
            'code', 'name', 'brand', 'organization_form', 'organization_form_name', 'vat_number', 'ssn', 'email',
            'url', 'phone', 'phone2', 'note', 'ordering',
        )


class OrganizationCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_create'
        model = Organization
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationRetrieveSerializer


class OrganizationUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_update'
        model = Organization
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationRetrieveSerializer


class OrganizationPartialUpdateSerializer(ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_partial_update'
        model = Organization
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationRetrieveSerializer


class OrganizationEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_enable'
        model = Organization
        fields = ()
        response_serializer = OrganizationRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class OrganizationDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_disable'
        model = Organization
        fields = ()
        response_serializer = OrganizationRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class OrganizationLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_light'
        model = Organization
        fields = ('id', 'status', 'status_display', 'name',)


# OWNER ORGANIZATION
class OwnerOrganizationSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_organization'
        model = models.OwnerOrganization
        fields = '__all__'


class OwnerOrganizationListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_organization_list'
        model = models.OwnerOrganization
        fields = (
            'id', 'status', 'status_display', 'category', 'organization_type', 'organization_type_name',
            'code', 'name', 'organization_form', 'organization_form_name', 'vat_number', 'ssn', 'email',
            'url', 'phone', 'ordering',
        )


class OwnerOrganizationRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_organization_retrieve'
        model = models.OwnerOrganization
        fields = (
            'id', 'status', 'status_display', 'category', 'organization_type', 'organization_type_name',
            'code', 'name', 'brand', 'organization_form', 'organization_form_name', 'vat_number', 'ssn', 'email',
            'url', 'phone', 'phone2', 'note', 'ordering',
        )


class OwnerOrganizationCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_organization_create'
        model = models.OwnerOrganization
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OwnerOrganizationRetrieveSerializer


class OwnerOrganizationUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_organization_update'
        model = models.OwnerOrganization
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OwnerOrganizationRetrieveSerializer


class OwnerOrganizationPartialUpdateSerializer(ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_organization_partial_update'
        model = models.OwnerOrganization
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OwnerOrganizationRetrieveSerializer


class OwnerOrganizationEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_organization_enable'
        model = models.OwnerOrganization
        fields = ()
        response_serializer = OwnerOrganizationRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class OwnerOrganizationDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_organization_disable'
        model = models.OwnerOrganization
        fields = ()
        response_serializer = OwnerOrganizationRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class OwnerOrganizationLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_organization_light'
        model = models.OwnerOrganization
        fields = ('id', 'status', 'status_display', 'name',)


# ORGANIZATION EMAIL
class OrganizationEmailSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_email'
        model = models.OrganizationEmail
        fields = '__all__'


class OrganizationEmailListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_email_list'
        model = models.OrganizationEmail
        fields = (
            'id', 'status', 'status_display', 'typology', 'typology_name', 'organization', 'organization_name',
            'email', 'is_primary', 'ordering',
        )


class OrganizationEmailRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_email_retrieve'
        model = models.OrganizationEmail
        fields = (
            'id', 'status', 'status_display', 'typology', 'typology_name', 'organization', 'organization_name',
            'email', 'is_primary', 'ordering',
        )


class OrganizationEmailCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_email_create'
        model = models.OrganizationEmail
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationEmailRetrieveSerializer


class OrganizationEmailUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_email_update'
        model = models.OrganizationEmail
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationEmailRetrieveSerializer


class OrganizationEmailPartialUpdateSerializer(ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_email_partial_update'
        model = models.OrganizationEmail
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationEmailRetrieveSerializer


class OrganizationEmailEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_email_enable'
        model = models.OrganizationEmail
        fields = ()
        response_serializer = OrganizationEmailRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class OrganizationEmailDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_email_disable'
        model = models.OrganizationEmail
        fields = ()
        response_serializer = OrganizationEmailRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class OrganizationEmailLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_email_light'
        model = models.OrganizationEmail
        fields = ('id', 'status', 'status_display', 'email', 'is_primary',)


# ORGANIZATION PHONE
class OrganizationPhoneSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_phone'
        model = models.OrganizationPhone
        fields = '__all__'


class OrganizationPhoneListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_phone_list'
        model = models.OrganizationPhone
        fields = (
            'id', 'status', 'status_display', 'typology', 'typology_name',
            'organization', 'organization_name', 'phone', 'is_primary', 'ordering',
        )


class OrganizationPhoneRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_phone_retrieve'
        model = models.OrganizationPhone
        fields = (
            'id', 'status', 'status_display', 'typology', 'typology_name',
            'organization', 'organization_name', 'phone', 'is_primary', 'ordering',
        )


class OrganizationPhoneCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_phone_create'
        model = models.OrganizationPhone
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationPhoneRetrieveSerializer


class OrganizationPhoneUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_phone_update'
        model = models.OrganizationPhone
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationPhoneRetrieveSerializer


class OrganizationPhonePartialUpdateSerializer(ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_phone_partial_update'
        model = models.OrganizationPhone
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationPhoneRetrieveSerializer


class OrganizationPhoneEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_phone_enable'
        model = models.OrganizationPhone
        fields = ()
        response_serializer = OrganizationPhoneRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class OrganizationPhoneDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_phone_disable'
        model = models.OrganizationPhone
        fields = ()
        response_serializer = OrganizationPhoneRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class OrganizationPhoneLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_phone_light'
        model = models.OrganizationPhone
        fields = ('id', 'status', 'status_display', 'phone', 'is_primary',)


# ORGANIZATION SOCIAL PAGE
class OrganizationSocialPageSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_social_page'
        model = models.OrganizationSocialPage
        fields = '__all__'


class OrganizationSocialPageListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_social_page_list'
        model = models.OrganizationSocialPage
        fields = (
            'id', 'status', 'status_display', 'social', 'get_social_display',
            'organization', 'organization_name', 'link', 'ordering',
        )


class OrganizationSocialPageRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_social_page_retrieve'
        model = models.OrganizationSocialPage
        fields = (
            'id', 'status', 'status_display', 'social', 'get_social_display',
            'organization', 'organization_name', 'link', 'ordering',
        )


class OrganizationSocialPageCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_social_page_create'
        model = models.OrganizationSocialPage
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationSocialPageRetrieveSerializer


class OrganizationSocialPageUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_social_page_update'
        model = models.OrganizationSocialPage
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationSocialPageRetrieveSerializer


class OrganizationSocialPagePartialUpdateSerializer(ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_social_page_partial_update'
        model = models.OrganizationSocialPage
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationSocialPageRetrieveSerializer


class OrganizationSocialPageEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_social_page_enable'
        model = models.OrganizationSocialPage
        fields = ()
        response_serializer = OrganizationSocialPageRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class OrganizationSocialPageDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_social_page_disable'
        model = models.OrganizationSocialPage
        fields = ()
        response_serializer = OrganizationSocialPageRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class OrganizationSocialPageLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_social_page_light'
        model = models.OrganizationSocialPage
        fields = ('id', 'status', 'status_display', 'link',)


# CONTACT ROLE
class ContactRoleSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_role'
        model = models.ContactRole
        fields = '__all__'


class ContactRoleListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_role_list'
        model = models.ContactRole
        fields = ('id', 'status', 'status_display', 'code', 'name', 'ordering')


class ContactRoleRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_role_retrieve'
        model = models.ContactRole
        fields = ('id', 'status', 'status_display', 'code', 'name', 'ordering')


class ContactRoleCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_role_create'
        model = models.ContactRole
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactRoleRetrieveSerializer


class ContactRoleUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_role_update'
        model = models.ContactRole
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactRoleRetrieveSerializer


class ContactRolePartialUpdateSerializer(ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_role_partial_update'
        model = models.ContactRole
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactRoleRetrieveSerializer


class ContactRoleEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_role_enable'
        model = models.ContactRole
        fields = ()
        response_serializer = ContactRoleRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class ContactRoleDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_role_disable'
        model = models.ContactRole
        fields = ()
        response_serializer = ContactRoleRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class ContactRoleLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_role_light'
        model = models.ContactRole
        fields = ('id', 'status', 'status_display', 'name',)


# CONTACT TITLE
class ContactTitleSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_title'
        model = models.ContactTitle
        fields = '__all__'


class ContactTitleListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_title_list'
        model = models.ContactTitle
        fields = ('code', 'status', 'status_display', 'name', 'abbreviation', 'ordering',)


class ContactTitleRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_title_retrieve'
        model = models.ContactTitle
        fields = ('code', 'status', 'status_display', 'name', 'abbreviation', 'ordering',)


class ContactTitleCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_title_create'
        model = models.ContactTitle
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactTitleRetrieveSerializer


class ContactTitleUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_title_update'
        model = models.ContactTitle
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactTitleRetrieveSerializer


class ContactTitlePartialUpdateSerializer(ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_title_partial_update'
        model = models.ContactTitle
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactTitleRetrieveSerializer


class ContactTitleEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_title_enable'
        model = models.ContactTitle
        fields = ()
        response_serializer = ContactTitleRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class ContactTitleDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_title_disable'
        model = models.ContactTitle
        fields = ()
        response_serializer = ContactTitleRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class ContactTitleLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_title_light'
        model = models.ContactTitle
        fields = ('code', 'status', 'status_display', 'name', 'abbreviation',)


# CONTACT
class ContactSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact'
        model = Contact
        fields = '__all__'


class ContactListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    roles = ContactRoleLightSerializer(many=True, read_only=True)

    class Meta:
        ref_name = 'v1_organization_contact_list'
        model = Contact
        fields = (
            'id', 'status', 'status_display', 'code', 'organization', 'organization_name',
            'title', 'title_name', 'language', 'language_name', 'user', 'user_email', 'roles',
            'last_name', 'first_name', 'email', 'mistakes', 'ordering',
        )


class ContactRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    roles = ContactRoleLightSerializer(many=True, read_only=True)

    class Meta:
        ref_name = 'v1_organization_contact_retrieve'
        model = Contact
        fields = (
            'id', 'status', 'status_display', 'code', 'organization', 'organization_name',
            'title', 'title_name', 'user', 'user_email',
            'roles', 'language', 'language_name', 'last_name', 'first_name', 'email', 'mistakes', 'ordering',
            'agree_privacy', 'agree_terms', 'agree_advertising', 'mail_profile_not_completed_sent',
            'avatar', 'note'
        )


class ContactCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_create'
        model = Contact
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactRetrieveSerializer


class ContactUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_update'
        model = Contact
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactRetrieveSerializer


class ContactPartialUpdateSerializer(ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_partial_update'
        model = Contact
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactRetrieveSerializer


class ContactEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_enable'
        model = Contact
        fields = ()
        response_serializer = ContactRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class ContactDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_disable'
        model = Contact
        fields = ()
        response_serializer = ContactRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class ContactLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_light'
        model = Contact
        fields = ('id', 'status', 'status_display', 'organization_name', 'full_name')


# OWNER CONTACT
class OwnerContactSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_contact'
        model = models.OwnerContact
        fields = '__all__'


class OwnerContactListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    roles = ContactRoleLightSerializer(many=True, read_only=True)

    class Meta:
        ref_name = 'v1_organization_owner_contact_list'
        model = models.OwnerContact
        fields = (
            'id', 'status', 'status_display', 'code', 'organization', 'organization_name',
            'title', 'title_name', 'language', 'language_name', 'user', 'user_email', 'roles',
            'last_name', 'first_name', 'email', 'mistakes', 'ordering',
        )


class OwnerContactRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    roles = ContactRoleLightSerializer(many=True, read_only=True)

    class Meta:
        ref_name = 'v1_organization_owner_contact_retrieve'
        model = models.OwnerContact
        fields = (
            'id', 'status', 'status_display', 'code', 'organization', 'organization_name',
            'title', 'title_name', 'user', 'user_email',
            'roles', 'language', 'language_name', 'last_name', 'first_name', 'email', 'mistakes', 'ordering',
            'agree_privacy', 'agree_terms', 'agree_advertising', 'mail_profile_not_completed_sent',
            'avatar', 'note'
        )


class OwnerContactCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_contact_create'
        model = models.OwnerContact
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OwnerContactRetrieveSerializer


class OwnerContactUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_contact_update'
        model = models.OwnerContact
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OwnerContactRetrieveSerializer


class OwnerContactPartialUpdateSerializer(ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_contact_partial_update'
        model = models.OwnerContact
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OwnerContactRetrieveSerializer


class OwnerContactEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_contact_enable'
        model = models.OwnerContact
        fields = ()
        response_serializer = OwnerContactRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class OwnerContactDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_contact_disable'
        model = models.OwnerContact
        fields = ()
        response_serializer = OwnerContactRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class OwnerContactLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_contact_light'
        model = models.OwnerContact
        fields = ('id', 'status', 'status_display', 'organization_name', 'full_name')


# CONTACT EMAIL
class ContactEmailSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_email'
        model = models.ContactEmail
        fields = '__all__'


class ContactEmailListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_email_list'
        model = models.ContactEmail
        fields = (
            'id', 'status', 'status_display', 'typology', 'typology_name',
            'contact', 'contact_full_name', 'contact_last_name', 'contact_first_name',
            'email', 'is_primary', 'ordering',
        )


class ContactEmailRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_email_retrieve'
        model = models.ContactEmail
        fields = (
            'id', 'status', 'status_display', 'typology', 'typology_name',
            'contact', 'contact_full_name', 'contact_last_name', 'contact_first_name',
            'email', 'is_primary', 'ordering',
        )


class ContactEmailCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_email_create'
        model = models.ContactEmail
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactEmailRetrieveSerializer


class ContactEmailUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_email_update'
        model = models.ContactEmail
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactEmailRetrieveSerializer


class ContactEmailPartialUpdateSerializer(ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_email_partial_update'
        model = models.ContactEmail
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactEmailRetrieveSerializer


class ContactEmailEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_email_enable'
        model = models.ContactEmail
        fields = ()
        response_serializer = ContactEmailRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class ContactEmailDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_email_disable'
        model = models.ContactEmail
        fields = ()
        response_serializer = ContactEmailRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class ContactEmailLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_email_light'
        model = models.ContactEmail
        fields = ('id', 'status', 'status_display', 'email', 'is_primary',)


# CONTACT PHONE
class ContactPhoneSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_phone'
        model = models.ContactPhone
        fields = '__all__'


class ContactPhoneListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_phone_list'
        model = models.ContactPhone
        fields = (
            'id', 'status', 'status_display', 'typology', 'typology_name',
            'contact', 'contact_full_name', 'contact_last_name', 'contact_first_name',
            'phone', 'is_primary', 'ordering',
        )


class ContactPhoneRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_phone_retrieve'
        model = models.ContactPhone
        fields = (
            'id', 'status', 'status_display', 'typology', 'typology_name',
            'contact', 'contact_full_name', 'contact_last_name', 'contact_first_name',
            'phone', 'is_primary', 'ordering',
        )


class ContactPhoneCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_phone_create'
        model = models.ContactPhone
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactPhoneRetrieveSerializer


class ContactPhoneUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_phone_update'
        model = models.ContactPhone
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactPhoneRetrieveSerializer


class ContactPhonePartialUpdateSerializer(ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_phone_partial_update'
        model = models.ContactPhone
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactPhoneRetrieveSerializer


class ContactPhoneEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_phone_enable'
        model = models.ContactPhone
        fields = ()
        response_serializer = ContactPhoneRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class ContactPhoneDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_phone_disable'
        model = models.ContactPhone
        fields = ()
        response_serializer = ContactPhoneRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class ContactPhoneLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_phone_light'
        model = models.ContactPhone
        fields = ('id', 'status', 'status_display', 'phone', 'is_primary',)


# CONTACT SOCIAL ACCOUNT
class ContactSocialAccountSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_social_account'
        model = models.ContactSocialAccount
        fields = '__all__'


class ContactSocialAccountListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_social_account_list'
        model = models.ContactSocialAccount
        fields = (
            'id', 'status', 'status_display', 'social', 'get_social_display',
            'contact', 'contact_full_name', 'contact_last_name', 'contact_first_name',
            'account', 'is_primary', 'ordering',
        )


class ContactSocialAccountRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_social_account_retrieve'
        model = models.ContactSocialAccount
        fields = (
            'id', 'status', 'status_display', 'social', 'get_social_display',
            'contact', 'contact_full_name', 'contact_last_name', 'contact_first_name',
            'account', 'is_primary', 'ordering',
        )


class ContactSocialAccountCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_social_account_create'
        model = models.ContactSocialAccount
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactSocialAccountRetrieveSerializer


class ContactSocialAccountUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_social_account_update'
        model = models.ContactSocialAccount
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactSocialAccountRetrieveSerializer


class ContactSocialAccountPartialUpdateSerializer(ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_social_account_partial_update'
        model = models.ContactSocialAccount
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactSocialAccountRetrieveSerializer


class ContactSocialAccountEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_social_account_enable'
        model = models.ContactSocialAccount
        fields = ()
        response_serializer = ContactSocialAccountRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class ContactSocialAccountDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_social_account_disable'
        model = models.ContactSocialAccount
        fields = ()
        response_serializer = ContactSocialAccountRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class ContactSocialAccountLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_social_account_light'
        model = models.ContactSocialAccount
        fields = ('id', 'status', 'status_display', 'account', 'is_primary',)
