# -*- coding: utf-8 -*-
from django.utils.translation import gettext_lazy as _

from .abstracts import AbstractContact, AbstractOrganization
from .contacts import *
from .organizations import *


def load_swapped_contact_proxy():
    from .. import managers
    if swapper.is_swapped("organization", "Contact"):
        Contact = swapper.load_model('organization', 'Contact')

        class OwnerContact(Contact):
            objects = managers.OwnerContactManager()

            class Meta:
                proxy = True
                verbose_name = _('owner contact')
                verbose_name_plural = _('owner contacts')
                permissions = (
                    ("list_ownercontact", "Can list owner contact"),
                    ("detail_ownercontact", "Can detail owner contact"),
                    ("enable_ownercontact", "Can enable owner contact"),
                    ("disable_ownercontact", "Can disable owner contact"),
                )
        globals()["OwnerContact"] = OwnerContact


def load_swapped_organization_proxy():
    from .. import managers
    if swapper.is_swapped("organization", "Organization"):
        Organization = swapper.load_model('organization', 'Organization')

        class OwnerOrganization(Organization):
            objects = managers.OwnerOrganizationManager()

            class Meta:
                proxy = True
                verbose_name = _('owner organization')
                verbose_name_plural = _('owner organizations')
                permissions = (
                    ("list_ownerorganization", "Can list owner organization"),
                    ("detail_ownerorganization", "Can detail owner organization"),
                    ("enable_ownerorganization", "Can enable owner organization"),
                    ("disable_ownerorganization", "Can disable owner organization"),
                )
        globals()["OwnerOrganization"] = OwnerOrganization
